# -*- coding: utf-8 -*-
from nose.tools import nottest
from op5helpers import *
import re

def perfdata(uri, code=200):
    url = api_endpoint + 'api/beta/perfdata/' + uri
    r = requests.get(url, verify=False, auth=authed_user)
    if r.status_code != code:
        raise Exception("Should have gotten %d, got %d\nurl: %s\nbody: %s" % (code, r.status_code, url, r.text))
    return r

def test_find_ds_for_service():
    # TODO: might be fixture dependent
    host = singlequote('linux-server1')
    service = singlequote('Cron process')
    url = 'fetch/?host='+host+'&service='+service
    r = perfdata(url)
    datasources = r.json()

    processes = False
    for ds in datasources:
        if ds['name'] == 'processes':
            processes = True
        ds_resource = requests.get(ds['resource'], auth=authed_user, verify=False)
        eq_(ds_resource.status_code, 200, "Tried to visit %s, got %d:\n%s" % (ds['resource'], ds_resource.status_code, ds_resource.text))

    ok_(processes, "Could not find the ds 'processes':\nurl: %s\nstatus: %d\nbody: %s" % (url, r.status_code, r.text))

def test_get_perfdata_aka_perfdatatool_fetch():
    # TODO: should be fixture dependent
    host = singlequote('linux-server1')
    service = singlequote('Cron process')
    ds = singlequote('processes')
    start = 1408901169
    end = 1408901212

    url = 'fetch/?host='+host+'&service='+service+'&ds='+ds+'&start='+str(start)+'&end='+str(end)
    r = perfdata(url)
    j = r.json()
    ok_(len(j), "No json found:\nurl: %s\nstatus: %d\nbody: %s" % (url, r.status_code, r.text))
    for datapoint in j:
        ok_(re.match('\d{10}', datapoint), 'Key in JSON dict should be a timestamp, was %s (value: %s)' % (str(datapoint), str(j[datapoint])))
        ok_(re.match('\d{10}|NaN', j[datapoint]), 'Values in JSON dict should be a number in scientific notation, was %s (key: %s)' % (j[datapoint], datapoint))
        break

def test_nonexisting_host():
    r = perfdata('fetch/?host=%s' % ('phantom_at_the_opera_cellar'), code=404)
    ok_('Host does not exist' in r.text, r.text)

def test_nonexisting_service():
    r = perfdata('fetch/?host=%s&service=%s' % ('linux-server1', 'per_oscarsson'), code=404)
    ok_('Service does not exist' in r.text, r.text)

def test_bad_ds():
    r = perfdata('fetch/?host=%s&service=%s&ds=%s' % ('linux-server1', 'Cron process', 'vattenglas'), code=404)
    ok_('DS does not exist' in r.text, r.text)

def test_bad_cf():
    r = perfdata('fetch/?host=%s&service=%s&ds=%s&cf=%s' % ('linux-server1', 'Cron process', 'processes', 'abc'), code=400)
    ok_('Invalid consolidation function' in r.text, r.text)

def check_start_end(url, wanted_code):
    perfdata(url, code=wanted_code)

@nottest
def test_start_end():
    tests = (
            ('2014-03-25', '2014-03-26', 200),
            ('2014-03-25', '2014-03-24', 400),
            ('abc', '123', 400),
            )
    for start, end, code in tests:
        yield perfdata, 'fetch/?host=%s&service=%s&ds=%s&start=%s&end=%s' % ('linux-server1', 'Cron process', 'rta', start, end), code

@nottest
def test_bad_auth(): pass

@nottest
def test_consistent_nan():
    # perfdata says "exact nan string format is platform dependent", we should use
    # our own.. let's decide on "NaN" right here and now
    # this test should also look for "NaN" in a help text
    # it's '-nan' on Calles Centos 6.5 (which ofc is canonical... )
    # TODO: should be fixture dependent
    pass

@nottest
def test_fetch_start_end_args():
    # TODO: definatively fixture dependent
    pass
